diff --git a/core/lib/Drupal/Core/Entity/ContentEntityBase.php b/core/lib/Drupal/Core/Entity/ContentEntityBase.php
index b5fccbd..d409b0a 100644
--- a/core/lib/Drupal/Core/Entity/ContentEntityBase.php
+++ b/core/lib/Drupal/Core/Entity/ContentEntityBase.php
@@ -294,7 +294,7 @@ public function isNewRevision() {
   public function isDefaultRevision($new_value = NULL) {
     $return = $this->isDefaultRevision;
     if (isset($new_value)) {
-      $this->isDefaultRevision = (bool) $new_value;
+      $this->setDefaultRevision($new_value);
     }
     return $return;
   }
@@ -302,6 +302,13 @@ public function isDefaultRevision($new_value = NULL) {
   /**
    * {@inheritdoc}
    */
+  public function setDefaultRevision($value = TRUE) {
+    $this->isDefaultRevision = (bool) $value;
+  }
+
+  /**
+   * {@inheritdoc}
+   */
   public function isRevisionTranslationAffected() {
     $field_name = 'revision_translation_affected';
     return $this->hasField($field_name) ? $this->get($field_name)->value : TRUE;
diff --git a/core/modules/block_content/src/Tests/BlockContentRevisionsTest.php b/core/modules/block_content/src/Tests/BlockContentRevisionsTest.php
index 720443d..c875625 100644
--- a/core/modules/block_content/src/Tests/BlockContentRevisionsTest.php
+++ b/core/modules/block_content/src/Tests/BlockContentRevisionsTest.php
@@ -76,7 +76,7 @@ public function testRevisions() {
     // This will create a new revision that is not "front facing".
     // Save this as a non-default revision.
     $loaded->setNewRevision();
-    $loaded->isDefaultRevision(FALSE);
+    $loaded->setDefaultRevision(FALSE);
     $loaded->body = $this->randomMachineName(8);
     $loaded->save();
 
diff --git a/core/modules/migrate/src/Plugin/migrate/destination/EntityRevision.php b/core/modules/migrate/src/Plugin/migrate/destination/EntityRevision.php
index 62469e7..d0bb443 100644
--- a/core/modules/migrate/src/Plugin/migrate/destination/EntityRevision.php
+++ b/core/modules/migrate/src/Plugin/migrate/destination/EntityRevision.php
@@ -56,7 +56,7 @@ protected function getEntity(Row $row, array $old_destination_id_values) {
       $entity->setNewRevision(TRUE);
     }
     $this->updateEntity($entity, $row);
-    $entity->isDefaultRevision(FALSE);
+    $entity->setDefaultRevision(FALSE);
     return $entity;
   }
 
diff --git a/core/modules/migrate/tests/src/Unit/destination/EntityRevisionTest.php b/core/modules/migrate/tests/src/Unit/destination/EntityRevisionTest.php
index f1e288e..f35fdc0 100644
--- a/core/modules/migrate/tests/src/Unit/destination/EntityRevisionTest.php
+++ b/core/modules/migrate/tests/src/Unit/destination/EntityRevisionTest.php
@@ -92,7 +92,7 @@ public function testGetEntityUpdateRevision() {
       ->willReturn($entity->reveal());
     // Make sure its set as an update and not the default revision.
     $entity->setNewRevision(FALSE)->shouldBeCalled();
-    $entity->isDefaultRevision(FALSE)->shouldBeCalled();
+    $entity->setDefaultRevision(FALSE)->shouldBeCalled();
 
     $row = new Row(['nid' => 1, 'vid' => 2], ['nid' => 1, 'vid' => 2]);
     $row->setDestinationProperty('vid', 2);
@@ -118,7 +118,7 @@ public function testGetEntityNewRevision() {
     $entity->enforceIsNew(FALSE)->shouldBeCalled();
     // And toggle this as new revision but not the default revision.
     $entity->setNewRevision(TRUE)->shouldBeCalled();
-    $entity->isDefaultRevision(FALSE)->shouldBeCalled();
+    $entity->setDefaultRevision(FALSE)->shouldBeCalled();
 
     // Assert we load the correct revision.
     $this->storage->load(1)
diff --git a/core/modules/node/src/Form/NodeRevisionRevertForm.php b/core/modules/node/src/Form/NodeRevisionRevertForm.php
index 275d55b..d5678fa 100644
--- a/core/modules/node/src/Form/NodeRevisionRevertForm.php
+++ b/core/modules/node/src/Form/NodeRevisionRevertForm.php
@@ -137,7 +137,7 @@ public function submitForm(array &$form, FormStateInterface $form_state) {
    */
   protected function prepareRevertedRevision(NodeInterface $revision, FormStateInterface $form_state) {
     $revision->setNewRevision();
-    $revision->isDefaultRevision(TRUE);
+    $revision->setDefaultRevision();
 
     return $revision;
   }
diff --git a/core/modules/node/src/Form/NodeRevisionRevertTranslationForm.php b/core/modules/node/src/Form/NodeRevisionRevertTranslationForm.php
index 05a4f6c..8b07d57 100644
--- a/core/modules/node/src/Form/NodeRevisionRevertTranslationForm.php
+++ b/core/modules/node/src/Form/NodeRevisionRevertTranslationForm.php
@@ -110,7 +110,7 @@ protected function prepareRevertedRevision(NodeInterface $revision, FormStateInt
     }
 
     $latest_revision_translation->setNewRevision();
-    $latest_revision_translation->isDefaultRevision(TRUE);
+    $latest_revision_translation->setDefaultRevision();
 
     return $latest_revision_translation;
   }
diff --git a/core/modules/node/src/Tests/NodeRevisionsTest.php b/core/modules/node/src/Tests/NodeRevisionsTest.php
index a1047f5..b347fca 100644
--- a/core/modules/node/src/Tests/NodeRevisionsTest.php
+++ b/core/modules/node/src/Tests/NodeRevisionsTest.php
@@ -187,12 +187,13 @@ function testRevisions() {
 
     // Make a new revision and set it to not be default.
     // This will create a new revision that is not "front facing".
+    /** @var \Drupal\node\NodeInterface $new_node_revision */
     $new_node_revision = clone $node;
     $new_body = $this->randomMachineName();
     $new_node_revision->body->value = $new_body;
     // Save this as a non-default revision.
     $new_node_revision->setNewRevision();
-    $new_node_revision->isDefaultRevision = FALSE;
+    $new_node_revision->setDefaultRevision(FALSE);
     $new_node_revision->save();
 
     $this->drupalGet('node/' . $node->id());
diff --git a/core/modules/system/src/Tests/Entity/EntityViewControllerTest.php b/core/modules/system/src/Tests/Entity/EntityViewControllerTest.php
index d9f36ff..42585ce 100644
--- a/core/modules/system/src/Tests/Entity/EntityViewControllerTest.php
+++ b/core/modules/system/src/Tests/Entity/EntityViewControllerTest.php
@@ -68,7 +68,7 @@ function testEntityViewController() {
     $entity_test_rev->save();
     $entity_test_rev->name->value = 'rev 2';
     $entity_test_rev->setNewRevision(TRUE);
-    $entity_test_rev->isDefaultRevision(TRUE);
+    $entity_test_rev->setDefaultRevision();
     $entity_test_rev->save();
     $this->drupalGet('entity_test_rev/' . $entity_test_rev->id() . '/revision/' . $entity_test_rev->revision_id->value . '/view');
     $this->assertRaw($entity_test_rev->label());
diff --git a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
index 0d4e5c4..fbc92a6 100644
--- a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
@@ -818,7 +818,7 @@ public function testForwardRevisions() {
     $current_values = $entity->{$this->figures}->getValue();
 
     $entity->setNewRevision(TRUE);
-    $entity->isDefaultRevision(FALSE);
+    $entity->setDefaultRevision(FALSE);
     $entity->{$this->figures}->setValue([
       'color' => 'red',
       'shape' => 'square'
diff --git a/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php b/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php
index 9bfa5e1..75f1802 100644
--- a/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php
@@ -76,10 +76,11 @@ public function testRevertRevisionAfterTranslation() {
 
     $this->assertTrue($entity->hasTranslation('de'));
 
+    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
     $entity = $storage->loadRevision($old_rev_id);
 
     $entity->setNewRevision();
-    $entity->isDefaultRevision(TRUE);
+    $entity->setDefaultRevision();
     $entity->save();
 
     $entity = $this->reloadEntity($entity);

diff --git a/core/lib/Drupal/Core/Entity/RevisionableInterface.php b/core/lib/Drupal/Core/Entity/RevisionableInterface.php
index 14690e3..65030f3 100644
--- a/core/lib/Drupal/Core/Entity/RevisionableInterface.php
+++ b/core/lib/Drupal/Core/Entity/RevisionableInterface.php
@@ -40,10 +40,21 @@ public function setNewRevision($value = TRUE);
   public function getRevisionId();
 
   /**
+   * Declares if the current revision is the default revision.
+   *
+   * @param bool $value
+   *   (optional) Whether or not the current revision is the default revision.
+   *   Defaults to TRUE.
+   */
+  public function setDefaultRevision($value = TRUE);
+
+  /**
    * Checks if this entity is the default revision.
    *
    * @param bool $new_value
    *   (optional) A Boolean to (re)set the isDefaultRevision flag.
    *
    * @return bool
    *   TRUE if the entity is the default revision, FALSE otherwise. If
@@ -40,10 +40,21 @@ public function setNewRevision($value = TRUE);
    *
    * @param bool $new_value
-   *   (optional) A Boolean to (re)set the isDefaultRevision flag.
+   *   (optional) A Boolean to (re)set the isDefaultRevision flag. This property
+   *   is deprecated and will be removed in Drupal 9.x. Use setDefaultRevision()
+   *   to set the default revision.
    *
    * @return bool